/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

//includes for project specific functions
#include "includes.h"
//external access to hall1 structure
extern HALL3 Hall1;

//define configuration constants readable by PLECS
PIL_CONFIG_DEF(uint32_t,SysClk, SYSCLK_HZ);
PIL_CONFIG_DEF(uint32_t,PWMTBPRD, PWMPRD);

/*
 * Function for initialization of all used override probes
 */
void initOverrideProbes(void)
{
   //Initialize Used Probes
   INIT_OPROBE(AIn.Idc);
   INIT_OPROBE(ControlVars.Iset);
   INIT_OPROBE(Hall1.HallGpio);
}

/*
 * Function for PIL framework callback definition
 */
void PilCallback(PIL_CtrlCallbackReq_t aCallbackReq)
{
   switch (aCallbackReq)
   {
      case PIL_CLBK_LEAVE_NORMAL_OPERATION_REQ:
         //Disables power stage
         stopControl();
         //Safe State for a simulation reached -> Confirmation to Framework
         PIL_allowPilSimulation();
         break;

      case PIL_CLBK_ENTER_NORMAL_OPERATION_REQ:
         //Prohibit simulation
         PIL_inhibitPilSimulation();
         //Reset of Controls, enabling power stage
         startControl();
         break;

      case PIL_CLBK_INITIALIZE_SIMULATION:
         //Reset of Controller before start of PIL simulation
         resetControl();
         EPwm3Regs.CMPA.half.CMPA = 0;
         EPwm1Regs.CMPA.half.CMPA = 7999;
         break;

      case PIL_CLBK_TERMINATE_SIMULATION:
         //Termination Request
         break;

      case PIL_CLBK_STOP_TIMERS:
         //Stop all timers
         StopCpuTimer0();
         break;

      case PIL_CLBK_START_TIMERS:
         //Start all timers
         StartCpuTimer0();
         break;
   }
}

