/*
 Copyright (c) 2014 by Plexim GmbH
 All rights reserved.

 NOTICE: This software embodies unpublished proprietary
 and trade secret information of Plexim GmbH.  Any copying,
 disclosure or transmission not expressly authorized by
 the owner is expressly prohibited. Plexim GmbH retains exclusive
 ownership of all intellectual property rights in this software,
 including all copyright, trade secret and patent rights.
 */

/**
 * @file angle.h
 * @brief Module for integrating and tracking angles.
 */

#ifndef ANGLE_H_
#define ANGLE_H_

#include "plx_types.h"

#ifdef __cplusplus
extern "C" {
#endif

#define PLX_ANGLE_Q_OMEGA 10
#define PLX_ANGLE_R_OMEGA 1024
#define PLX_ANGLE_Q_ANGLE 16
#define PLX_ANGLE_R_ANGLE 65536

#define PLX_ANGLE_Q_ONE 14
#define PLX_ANGLE_R_ONE 16384

typedef struct PLX_ANGLE_OBJ
{
	int16_t data[10];
} PLX_ANGLE_Obj_t;

typedef struct PLX_ANGLE_Obj_t *PLX_ANGLE_Handle_t;

extern PLX_ANGLE_Handle_t PLX_ANGLE_init(void *aMemory, const size_t aNumBytes);

extern void PLX_ANGLE_configure(PLX_ANGLE_Handle_t aAngleHandle, int16_t aPuFrefTsScaling, int16_t aMaxRevCount);

extern void PLX_ANGLE_reset(PLX_ANGLE_Handle_t aAngleHandle, uint16_t aAngle0);

extern void PLX_ANGLE_track(PLX_ANGLE_Handle_t aAngleHandle, uint16_t aAngle);

extern void PLX_ANGLE_accumulate(PLX_ANGLE_Handle_t aAngleHandle, int16_t aW, uint16_t *aAngle);

extern int16_t PLX_ANGLE_getRevCounter(PLX_ANGLE_Handle_t aAngleHandle);

extern int16_t PLX_ANGLE_getSignedDiff(PLX_ANGLE_Handle_t aAngleHandle1, PLX_ANGLE_Handle_t aAngleHandle2);

#ifdef __cplusplus
}
#endif // extern "C"

#endif /* PI_H_ */
